@@ -37,13 +37,13 @@ class GPCAMInProcessEngine(Engine):
         self.reset()
 
         if dimensionality == 2:
-            self.graphs = [Variance(),
-                           Score(),
-                           GPCamPosteriorCovariance(),
+            self.graphs = [GPCamPosteriorCovariance(),
                            GPCamAcquisitionFunction(),
                            GPCamPosteriorMean(),
                            # GPCamAverageCovariance(),
-                           Table()]
+                           Table(),
+                           Variance(),
+                           Score()]
         elif dimensionality > 2:
             self.graphs = [GPCamPosteriorCovariance(),
                            # GPCamAverageCovariance(),
@@ -116,11 +116,12 @@ class GPCAMInProcessEngine(Engine):
         for graph in self.graphs:
             graph.compute(data, self)
 
-    def request_targets(self, position, n):
+    def request_targets(self, position):
         kwargs = {key: self.parameters[key] for key in ['acquisition_function', 'method', 'pop_size', 'tol']}
         kwargs.update({'bounds': np.asarray([[self.parameters[('bounds', f'axis_{i}_{edge}')]
                                               for edge in ['min', 'max']]
                                              for i in range(self.dimensionality)])})
+        n = self.parameters['n']
         return self.optimizer.ask(position, n, acquisition_function=acquisition_functions[kwargs.pop('acquisition_function')], **kwargs)['x']
 
     def train(self):
@@ -135,4 +136,5 @@ class GPCAMInProcessEngine(Engine):
                                          np.asarray([self.parameters[('hyperparameters', f'hyperparameter_{i}')]
                                                      for i in range(self.dimensionality + 1)]), method=method)
                     self._completed_training[method].add(N)
-                    break  # only does global training if specified for both
+                    # return  # only does global training if specified for both
+        return True
\ No newline at end of file
